cubek-convolution 0.3.0

CubeK: Convolution Kernels
docs.rs failed to build cubek-convolution-0.3.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: cubek-convolution-0.3.0-pre.4

CubeCL Convolution Kernels Engine