pub struct RuntimeArgs {
pub shape_k: u32,
pub channels: u32,
pub padded_channels: FastDivmod<u32>,
pub operation: ConvolutionOperation,
}Fields
shape_k: u32channels: u32padded_channels: FastDivmod<u32>operation: ConvolutionOperationTrait Implementations
Sourceimpl Clone for RuntimeArgs
impl Clone for RuntimeArgs
Sourcefn clone(&self) -> RuntimeArgs
fn clone(&self) -> RuntimeArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CubeType for RuntimeArgs
impl CubeType for RuntimeArgs
Sourceimpl<TO: TilingOrder> FullLoadingStrategy<RuntimeArgs> for AsyncFullCyclicLoading<TO>
impl<TO: TilingOrder> FullLoadingStrategy<RuntimeArgs> for AsyncFullCyclicLoading<TO>
Sourcetype TilingLayout = ContiguousTilingLayout<TO>
type TilingLayout = ContiguousTilingLayout<TO>
The layout describing how data is tiled across the stage.
Sourcetype SyncStrategy = AsyncCopy
type SyncStrategy = AsyncCopy
The synchronization strategy that should be used with this loading strategy
Sourcetype Job<EG: Numeric, NG: Size, ES: Numeric, NS: Size> = AsyncFullCyclicJob
type Job<EG: Numeric, NG: Size, ES: Numeric, NS: Size> = AsyncFullCyclicJob
The LoadingJob for this strategy.
type Stage = StridedStageFamily
Sourcefn new_job<EG: Numeric, NG: Size, ES: Numeric, NS: Size>(
runtime_args: RuntimeArgs,
config: GlobalReaderConfig,
) -> Self::Job<EG, NG, ES, NS>
fn new_job<EG: Numeric, NG: Size, ES: Numeric, NS: Size>( runtime_args: RuntimeArgs, config: GlobalReaderConfig, ) -> Self::Job<EG, NG, ES, NS>
Returns the job with preliminary calculations done.
fn __expand_new_job<EG: Numeric, NG: Size, ES: Numeric, NS: Size>( scope: &Scope, runtime_args: <RuntimeArgs as CubeType>::ExpandType, config: GlobalReaderConfig, ) -> <Self::Job<EG, NG, ES, NS> as CubeType>::ExpandType
const SHOULD_CLEAR: bool = false
Sourceimpl FullLoadingStrategy<RuntimeArgs> for AsyncFullStridedLoading
impl FullLoadingStrategy<RuntimeArgs> for AsyncFullStridedLoading
Sourcetype TilingLayout = StridedTilingLayout
type TilingLayout = StridedTilingLayout
The layout describing how data is tiled across the stage.
Sourcetype SyncStrategy = AsyncCopy
type SyncStrategy = AsyncCopy
The synchronization strategy that should be used with this loading strategy
Sourcetype Job<EG: Numeric, NG: Size, ES: Numeric, NS: Size> = AsyncFullStridedJob
type Job<EG: Numeric, NG: Size, ES: Numeric, NS: Size> = AsyncFullStridedJob
The LoadingJob for this strategy.
type Stage = StridedStageFamily
Sourcefn new_job<EG: Numeric, NG: Size, ES: Numeric, NS: Size>(
runtime_args: RuntimeArgs,
config: GlobalReaderConfig,
) -> Self::Job<EG, NG, ES, NS>
fn new_job<EG: Numeric, NG: Size, ES: Numeric, NS: Size>( runtime_args: RuntimeArgs, config: GlobalReaderConfig, ) -> Self::Job<EG, NG, ES, NS>
Returns the job with preliminary calculations done.
fn __expand_new_job<EG: Numeric, NG: Size, ES: Numeric, NS: Size>( scope: &Scope, runtime_args: <RuntimeArgs as CubeType>::ExpandType, config: GlobalReaderConfig, ) -> <Self::Job<EG, NG, ES, NS> as CubeType>::ExpandType
const SHOULD_CLEAR: bool = false
Sourceimpl LaunchArg for RuntimeArgs
impl LaunchArg for RuntimeArgs
Sourcetype RuntimeArg<R: Runtime> = RuntimeArgsLaunch<R>
type RuntimeArg<R: Runtime> = RuntimeArgsLaunch<R>
The runtime argument for the kernel.
Sourcetype CompilationArg = RuntimeArgsCompilationArg
type CompilationArg = RuntimeArgsCompilationArg
Compilation argument.
fn register<R: Runtime>( arg: Self::RuntimeArg<R>, launcher: &mut KernelLauncher<R>, ) -> Self::CompilationArg
Sourcefn expand(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as CubeType>::ExpandType
fn expand( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as CubeType>::ExpandType
Register a variable during compilation that fill the
KernelBuilder.Auto Trait Implementations
impl Freeze for RuntimeArgs
impl RefUnwindSafe for RuntimeArgs
impl Send for RuntimeArgs
impl Sync for RuntimeArgs
impl Unpin for RuntimeArgs
impl UnsafeUnpin for RuntimeArgs
impl UnwindSafe for RuntimeArgs