pub struct RuntimeArgsExpand {
pub shape_k: <u32 as CubeType>::ExpandType,
pub channels: <u32 as CubeType>::ExpandType,
pub padded_channels: <FastDivmod<u32> as CubeType>::ExpandType,
pub operation: ConvolutionOperation,
}Fields
shape_k: <u32 as CubeType>::ExpandTypechannels: <u32 as CubeType>::ExpandTypepadded_channels: <FastDivmod<u32> as CubeType>::ExpandTypeoperation: ConvolutionOperationTrait Implementations
Sourceimpl AsMutExpand for RuntimeArgsExpand
impl AsMutExpand for RuntimeArgsExpand
fn __expand_ref_mut_method(&mut self, _: &Scope) -> &mut Self
fn __expand_as_mut_method(&mut self, scope: &Scope) -> &mut T
Sourceimpl AsRefExpand for RuntimeArgsExpand
impl AsRefExpand for RuntimeArgsExpand
fn __expand_ref_method(&self, _: &Scope) -> &Self
fn __expand_as_ref_method(&self, scope: &Scope) -> &T
Sourceimpl Clone for RuntimeArgsExpand
impl Clone for RuntimeArgsExpand
Sourcefn clone(&self) -> RuntimeArgsExpand
fn clone(&self) -> RuntimeArgsExpand
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CubeDebug for RuntimeArgsExpand
impl CubeDebug for RuntimeArgsExpand
Sourcefn set_debug_name(&self, scope: &Scope, name: &'static str)
fn set_debug_name(&self, scope: &Scope, name: &'static str)
Set the debug name of this type’s expansion. Should do nothing for types that don’t appear
at runtime
Sourceimpl ExpandTypeClone for RuntimeArgsExpand
impl ExpandTypeClone for RuntimeArgsExpand
Sourcefn clone_unchecked(&self) -> Self
fn clone_unchecked(&self) -> Self
Unchecked clone that only clones the conceptual runtime value. Should only be used in cases
where each copy is used in a mutually exclusive branch (i.e. match, runtime enums). This is
intentionally separated from Rust’s
Clone semantics and should only be used for the
conceptual expand values, never real data. Using two values in the same branch is undefined
behaviour.Sourceimpl IntoExpand for RuntimeArgsExpand
impl IntoExpand for RuntimeArgsExpand
type Expand = RuntimeArgsExpand
fn into_expand(self, _: &Scope) -> Self