pub struct Im2colLayoutExpand {
pub shape_out: <Sequence<FastDivmod<u32>> as CubeType>::ExpandType,
pub padded_channels: <FastDivmod<u32> as CubeType>::ExpandType,
pub rows: <u32 as CubeType>::ExpandType,
pub cols: <u32 as CubeType>::ExpandType,
pub params: ConvolutionParams,
pub config: GlobalLayoutConfig,
}Fields
shape_out: <Sequence<FastDivmod<u32>> as CubeType>::ExpandTypepadded_channels: <FastDivmod<u32> as CubeType>::ExpandTyperows: <u32 as CubeType>::ExpandTypecols: <u32 as CubeType>::ExpandTypeparams: ConvolutionParamsconfig: GlobalLayoutConfigTrait Implementations
Sourceimpl AsMutExpand for Im2colLayoutExpand
impl AsMutExpand for Im2colLayoutExpand
fn __expand_ref_mut_method(&mut self, _: &Scope) -> &mut Self
fn __expand_as_mut_method(&mut self, scope: &Scope) -> &mut T
Sourceimpl AsRefExpand for Im2colLayoutExpand
impl AsRefExpand for Im2colLayoutExpand
fn __expand_ref_method(&self, _: &Scope) -> &Self
fn __expand_as_ref_method(&self, scope: &Scope) -> &T
Sourceimpl CubeDebug for Im2colLayoutExpand
impl CubeDebug for Im2colLayoutExpand
Sourcefn set_debug_name(&self, scope: &Scope, name: &'static str)
fn set_debug_name(&self, scope: &Scope, name: &'static str)
Set the debug name of this type’s expansion. Should do nothing for types that don’t appear
at runtime
Sourceimpl ExpandTypeClone for Im2colLayoutExpand
impl ExpandTypeClone for Im2colLayoutExpand
Sourcefn clone_unchecked(&self) -> Self
fn clone_unchecked(&self) -> Self
Unchecked clone that only clones the conceptual runtime value. Should only be used in cases
where each copy is used in a mutually exclusive branch (i.e. match, runtime enums). This is
intentionally separated from Rust’s
Clone semantics and should only be used for the
conceptual expand values, never real data. Using two values in the same branch is undefined
behaviour.Sourceimpl IntoExpand for Im2colLayoutExpand
impl IntoExpand for Im2colLayoutExpand
type Expand = Im2colLayoutExpand
fn into_expand(self, _: &Scope) -> Self
Sourceimpl IntoMut for Im2colLayoutExpand
impl IntoMut for Im2colLayoutExpand
Sourceimpl LayoutExpand for Im2colLayoutExpand
impl LayoutExpand for Im2colLayoutExpand
Sourcetype Coordinates = (usize, u32, u32)
type Coordinates = (usize, u32, u32)
The coordinate type used by the conceptual tensor represented by this layout, i.e.
(u32, u32, u32) for a fixed-rank 3D tensor.
This does not have to match the rank of the underlying storage (if applicable).
It’s only how the tensor is interpreted (viewed) by the code.Sourcetype SourceCoordinates = NhwcCoords
type SourceCoordinates = NhwcCoords
The coordinate type used by the inner storage wrapped in this layout, i.e.
u32 for
Array, or (u32, u32) for a 2D view.fn __expand_to_source_pos_method( &self, scope: &Scope, pos: <Self::Coordinates as CubeType>::ExpandType, ) -> <NhwcCoords as CubeType>::ExpandType
fn __expand_shape_method( &self, scope: &Scope, ) -> <Self::Coordinates as CubeType>::ExpandType
fn __expand_to_source_pos_checked_method( &self, scope: &Scope, pos: <Self::Coordinates as CubeType>::ExpandType, ) -> (<NhwcCoords as CubeType>::ExpandType, <bool as CubeType>::ExpandType)
fn __expand_is_in_bounds_method( &self, scope: &Scope, pos: <Self::Coordinates as CubeType>::ExpandType, ) -> <bool as CubeType>::ExpandType