pub struct NhwcLayoutExpand {
pub stride_batch: <usize as CubeType>::ExpandType,
pub strides_spatial: <Sequence<usize> as CubeType>::ExpandType,
pub stride_channel: <usize as CubeType>::ExpandType,
pub shape_batch: <u32 as CubeType>::ExpandType,
pub shapes_spatial: <Sequence<u32> as CubeType>::ExpandType,
pub shape_channel: <u32 as CubeType>::ExpandType,
pub vector_size: VectorSize,
pub checks: EnumSet<NhwcCheck>,
}Fields
stride_batch: <usize as CubeType>::ExpandTypestrides_spatial: <Sequence<usize> as CubeType>::ExpandTypestride_channel: <usize as CubeType>::ExpandTypeshape_batch: <u32 as CubeType>::ExpandTypeshapes_spatial: <Sequence<u32> as CubeType>::ExpandTypeshape_channel: <u32 as CubeType>::ExpandTypevector_size: VectorSizechecks: EnumSet<NhwcCheck>Trait Implementations
Sourceimpl AsMutExpand for NhwcLayoutExpand
impl AsMutExpand for NhwcLayoutExpand
fn __expand_ref_mut_method(&mut self, _: &Scope) -> &mut Self
fn __expand_as_mut_method(&mut self, scope: &Scope) -> &mut T
Sourceimpl AsRefExpand for NhwcLayoutExpand
impl AsRefExpand for NhwcLayoutExpand
fn __expand_ref_method(&self, _: &Scope) -> &Self
fn __expand_as_ref_method(&self, scope: &Scope) -> &T
Sourceimpl CubeDebug for NhwcLayoutExpand
impl CubeDebug for NhwcLayoutExpand
Sourcefn set_debug_name(&self, scope: &Scope, name: &'static str)
fn set_debug_name(&self, scope: &Scope, name: &'static str)
Set the debug name of this type’s expansion. Should do nothing for types that don’t appear
at runtime
Sourceimpl ExpandTypeClone for NhwcLayoutExpand
impl ExpandTypeClone for NhwcLayoutExpand
Sourcefn clone_unchecked(&self) -> Self
fn clone_unchecked(&self) -> Self
Unchecked clone that only clones the conceptual runtime value. Should only be used in cases
where each copy is used in a mutually exclusive branch (i.e. match, runtime enums). This is
intentionally separated from Rust’s
Clone semantics and should only be used for the
conceptual expand values, never real data. Using two values in the same branch is undefined
behaviour.Sourceimpl IntoExpand for NhwcLayoutExpand
impl IntoExpand for NhwcLayoutExpand
type Expand = NhwcLayoutExpand
fn into_expand(self, _: &Scope) -> Self
Sourceimpl IntoMut for NhwcLayoutExpand
impl IntoMut for NhwcLayoutExpand
Sourceimpl LayoutExpand for NhwcLayoutExpand
impl LayoutExpand for NhwcLayoutExpand
Sourcetype Coordinates = NhwcCoords
type Coordinates = NhwcCoords
The coordinate type used by the conceptual tensor represented by this layout, i.e.
(u32, u32, u32) for a fixed-rank 3D tensor.
This does not have to match the rank of the underlying storage (if applicable).
It’s only how the tensor is interpreted (viewed) by the code.Sourcetype SourceCoordinates = usize
type SourceCoordinates = usize
The coordinate type used by the inner storage wrapped in this layout, i.e.
u32 for
Array, or (u32, u32) for a 2D view.fn __expand_to_source_pos_method( &self, scope: &Scope, pos: <Self::Coordinates as CubeType>::ExpandType, ) -> <Self::SourceCoordinates as CubeType>::ExpandType
fn __expand_to_source_pos_checked_method( &self, scope: &Scope, pos: <Self::Coordinates as CubeType>::ExpandType, ) -> (<Self::SourceCoordinates as CubeType>::ExpandType, <bool as CubeType>::ExpandType)
fn __expand_is_in_bounds_method( &self, scope: &Scope, pos: <Self::Coordinates as CubeType>::ExpandType, ) -> <bool as CubeType>::ExpandType
fn __expand_shape_method( &self, scope: &Scope, ) -> <Self::Coordinates as CubeType>::ExpandType