pub trait ConcreteInputsFactory<A: Routine<RuntimeArgs>>: LaunchArg {
// Required method
fn create<R: Runtime>(
lhs: InputBinding<R>,
rhs: InputBinding<R>,
bias: Option<InputBinding<R>>,
blueprint: &A::Blueprint,
problem: &ConvolutionProblem,
dtypes: &MatmulElems,
) -> (Self::RuntimeArg<R>, RuntimeArgsLaunch<R>);
}Expand description
Create the input runtime arguments for a matmul kernel that works on concrete inputs and output (not fused).
Required Methods
fn create<R: Runtime>( lhs: InputBinding<R>, rhs: InputBinding<R>, bias: Option<InputBinding<R>>, blueprint: &A::Blueprint, problem: &ConvolutionProblem, dtypes: &MatmulElems, ) -> (Self::RuntimeArg<R>, RuntimeArgsLaunch<R>)
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.